import { HStack, Icon, transform } from '@chakra-ui/react'
import { FaRegStar, FaStar } from 'react-icons/fa6'
import React, { useMemo, useState } from 'react'
import { getConfigValue } from '@brojs/cli'
import { useDispatch, useSelector } from 'react-redux'

import { stars } from '../__data__/context'
import { useUsers } from '../hooks'
import { setStars } from '../__data__/actions/stars'
import { api } from '../__data__/service/main'


const useStars = (currentRated, starsCount) => {
  const [rated, setRated] = useState(currentRated)
  const stars = useMemo(
    () =>
      Array.from({ length: starsCount }).map((_, index) => index + 1 > rated),
    [starsCount, rated],
  )

  return {
    setRated,
    stars,
  }
}

export const Stars = ({
  count,
  // rated,
  // setRated,
  userId,
}: {
  count: number
  userId: string
  // rated: number
  // setRated: (rate: number) => void
}) => {
  // const {
  //   stars,
  //   setRated: starsSetRated
  // } = useStars(rated, count)
  // const { setUserRate } = useUsers(state => state[userId].rated)
  // const rate = useSelector((store) => store.stars.friends[userId as '2']) ?? 0
  const dispatch = useDispatch()
  const { data, error, isLoading } = api.useUsersQuery(void 0)
  const [updateRating, updateRatingRequest] = api.useUpdateRatingMutation()
  
  const rate = data?.[userId]?.rated ?? 0

  const handleStarsClick = (value: number) => {
    // dispatch(setStars({ id: userId, value }))
    updateRating({ userId, rating: value })
    // setUserRate(userId, stars)
    // fetch(getConfigValue('dry-wash.api.url') + '/user-rate', {
    //   method: 'POST',
    //   headers: {
    //     'Content-Type': 'application/json',
    //   },
    //   body: JSON.stringify({
    //     userId,
    //     stars,
    //   }),
    // })
  }

  return (
    <HStack>
      {Array.from({ length: count }).map((_, index) =>
        index + 1 > rate ? (
          <Icon
            key={index}
            color="orange.400"
            cursor="pointer"
            onClick={() => handleStarsClick(index + 1)}
          >
            <FaRegStar />
          </Icon>
        ) : (
          <Icon
            key={index}
            color="orange.400"
            cursor="pointer"
            onClick={() => handleStarsClick(index + 1)}
          >
            <FaStar />
          </Icon>
        ),
      )}
    </HStack>
  )
}
